####################################################################
#
#This software is released under the GPL.  Please
#see the included LICENSE file.
#
#Copyright (C) 2001  Michael Spiceland
#Copyright (C) 2001  Jay Kline
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#Use this script at your own risk!  I make no 
#warranties that it is hack proof!
#
#
# This script is part of Mike's Perl Script Archive at
# www.mikespice.com/perl/
#
# Edited by Jay Kline www.slushpupie.com
#
####################################################################

####################################################################
# printable calendar options
# - see the README.PRINTABLE-CALENDARS for information where to get
# - the required programs.  You must have pscal and ps2pdf installed
# 
# - to enable clicking to make PDF printable calendars from the
# current calendar, just specify the path to pscal below.
####################################################################
# specify the FULL PATH to pscal executable THIS ENABLES THE LINK
$pscal = '/usr/local/bin/pscal';
# specify the FULL PATH to ps2pdf executable
$ps2pdf = '/usr/local/bin/ps2pdf';
# A writable path for the script to place the PDF's of the calendars
# This directory should allow for users to have read access.  Some
# sometimes cgi-bin/ directories don't allow this so /var/www/html/
# or www/ would be a good choice
$calendar_path = '/home/username/public_html';
# URL to the same path for using in hyperlinks
$calendar_url = 'http://domain.com/';
$csslink = 'http://domain.com/calendar.css';
# Do you want to allow importing from Outlook .csv files?
$import = 'yes';


return 1;
